<?php
// class-paymink-gateway.php

if ( ! defined( 'ABSPATH' ) ) {
    exit; // Prevent direct access
}

if ( ! class_exists( 'WC_Payment_Gateway' ) ) {
    return; // WooCommerce Payment Gateway class is not available
}

class WC_Paymink_Gateway extends WC_Payment_Gateway {

    public function __construct() {
        $this->id = 'paymink';
        $this->method_title = 'Paymink Payment';
        $this->method_description = 'Secure payments via Paymink.';
        $this->supports = ['products', 'refunds']; // Add support for products and refunds

        // Load settings
        $this->init_form_fields();
        $this->init_settings();

        $this->title = $this->get_option('title');
        $this->description = $this->get_option('description');
        $this->public_key = $this->get_option('public_key');
        $this->secret_key = $this->get_option('secret_key');
        $this->test_mode = $this->get_option('test_mode') === 'yes';

        // Save admin settings
        add_action('woocommerce_update_options_payment_gateways_' . $this->id, [$this, 'process_admin_options']);
    }

    public function init_form_fields() {
        $this->form_fields = [
            'enabled' => [
                'title' => 'Enable/Disable',
                'type' => 'checkbox',
                'label' => 'Enable Paymink Payment',
                'default' => 'yes'
            ],
            'title' => [
                'title' => 'Title',
                'type' => 'text',
                'default' => 'Paymink Payment'
            ],
            'description' => [
                'title' => 'Description',
                'type' => 'textarea',
                'default' => 'Pay securely using Paymink.'
            ],
            'public_key' => [
                'title' => 'Public Key',
                'type' => 'text',
                'default' => ''
            ],
            'secret_key' => [
                'title' => 'Secret Key',
                'type' => 'text',
                'default' => ''
            ],
            'test_mode' => [
                'title' => 'Test Mode',
                'type' => 'checkbox',
                'label' => 'Enable Test Mode',
                'default' => 'yes'
            ]
        ];
    }

    public function process_payment($order_id) {
        $order = wc_get_order($order_id);

        // Log order information
        error_log('Processing Order ID: ' . $order_id);

        // Call the Paymink API to initiate payment
        $redirect_url = Paymink_API::initiate_payment($order, $this->public_key, $this->secret_key, $this->test_mode);

        // Log the API response
        error_log('Paymink Response: ' . print_r($redirect_url, true));

        if (empty($redirect_url) || !filter_var($redirect_url, FILTER_VALIDATE_URL)) {
            // Log failure if no valid redirect URL is returned
            error_log('Redirect URL is invalid or empty');

            return [
                'result' => 'failure',
                'message' => 'Error processing payment. Please try again.'
            ];
        }

        // Return success with redirect URL
        return [
            'result' => 'success',
            'redirect' => $redirect_url
        ];
    }
}
?>
