<?php
class Paymink_API {

    public static function initiate_payment($order, $public_key, $secret_key, $test_mode) {
        if ( ! is_a( $order, 'WC_Order' ) ) {
            return null;
        }

        // Set API URL based on test mode
        $url = $test_mode ? 'https://paymink.com/test/payment/initiate' : 'https://paymink.com/payment/initiate';
        
        // Prepare payment parameters
        $parameters = [
            'identifier' => $order->get_id(),
            'currency' => $order->get_currency(),
            'amount' => $order->get_total(),
            'gateway_methods' => [], // Leave empty or specify
            'details' => 'Purchase from ' . get_bloginfo('name'),
            'ipn_url' => esc_url( home_url( '/paymink-webhook' ) ),  // WP IPN URL
            'cancel_url' => esc_url( home_url( '/cancel' ) ), // Cancel URL
            'success_url' => home_url( '/order-success/?invoice_id=' . $order->get_id() . '&email=' . rawurlencode($order->get_billing_email()) ),
            'public_key' => $public_key,
            'site_name' => get_bloginfo('name'),
            'site_logo' => esc_url( home_url( '/assets/logo.png' ) ),
            'checkout_theme' => 'light',  // Dark or Light
            'customer' => [
                'first_name' => $order->get_billing_first_name(),
                'last_name' => $order->get_billing_last_name(),
                'email' => $order->get_billing_email(),
                'mobile' => $order->get_billing_phone(),
            ],
            'shipping_info' => [
                'address_one' => $order->get_shipping_address_1(),
                'address_two' => $order->get_shipping_address_2(),
                'city' => $order->get_shipping_city(),
                'state' => $order->get_shipping_state(),
                'postcode' => $order->get_shipping_postcode(),
                'country' => $order->get_shipping_country(),
            ],
            'billing_info' => [
                'address_one' => $order->get_billing_address_1(),
                'address_two' => $order->get_billing_address_2(),
                'city' => $order->get_billing_city(),
                'state' => $order->get_billing_state(),
                'postcode' => $order->get_billing_postcode(),
                'country' => $order->get_billing_country(),
            ]
        ];

        // Convert parameters to query string
        $parameters = http_build_query($parameters);

        // Initialize cURL
        $ch = curl_init();
        curl_setopt($ch, CURLOPT_SSL_VERIFYHOST, 2);
        curl_setopt($ch, CURLOPT_URL, $url);
        curl_setopt($ch, CURLOPT_POSTFIELDS, $parameters);
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
        $response = curl_exec($ch);
        curl_close($ch);

        // Log response for debugging
        error_log("Paymink API Response: " . $response);

        // Decode the response
        $response_data = json_decode($response, true);

        if (isset($response_data['status']) && $response_data['status'] === 'success') {
            return $response_data['redirect_url'];
        }

        return null;
    }
}
