<?php
// Ensure WordPress is loaded
if (!defined('ABSPATH')) {
    exit;
}

// Get the global WordPress query object
global $wp_query;

// Ensure both invoice ID and email are available and valid
$invoice_id = isset($_GET['invoice_id']) ? sanitize_text_field($_GET['invoice_id']) : '';
$email = isset($_GET['email']) ? sanitize_email($_GET['email']) : '';

get_header(); // Include the theme's header

?>

<div class="order-success-page">
    <div class="container">
        <?php 
        if (!empty($invoice_id) && !empty($email)) :
            // Query the order based on the invoice ID
            $order = wc_get_order($invoice_id);
            
            if ($order) :
                // Check if the order's billing email matches the provided email
                if ($order->get_billing_email() === $email) :
                    ?>
                    <div class="order-details-box">
                        <h2 class="order-title">Order Details for Invoice #<?php echo esc_html($invoice_id); ?></h2>
                        <div class="order-info">
                            <p><strong>Customer Name:</strong> <?php echo esc_html($order->get_billing_first_name()) . ' ' . esc_html($order->get_billing_last_name()); ?></p>
                            <p><strong>Email:</strong> <?php echo esc_html($order->get_billing_email()); ?></p>
                            <p><strong>Order Amount:</strong> <?php echo esc_html($order->get_total()); ?></p>
                            <p><strong>Order Date:</strong> <?php echo esc_html($order->get_date_created()->date('Y-m-d H:i:s')); ?></p>
                        </div>

                        <h3 class="order-items-title">Items:</h3>
                        <ul class="order-items-list">
                            <?php foreach ($order->get_items() as $item_id => $item) : ?>
                                <li class="order-item">
                                    <strong><?php echo esc_html($item->get_name()); ?></strong> 
                                    x <?php echo esc_html($item->get_quantity()); ?>
                                </li>
                            <?php endforeach; ?>
                        </ul>

                        <div class="billing-address">
                            <?php
                            // Optionally, display billing address if needed
                            $billing_address = $order->get_billing_address_1() . ' ' . $order->get_billing_city() . ', ' . $order->get_billing_postcode();
                            ?>
                            <p><strong>Billing Address:</strong> <?php echo esc_html($billing_address); ?></p>
                        </div>
                    </div>
                <?php else : ?>
                    <div class="error-message">
                        <p>Order not found or email does not match.</p>
                    </div>
                <?php endif; ?>
            <?php else : ?>
                <div class="error-message">
                    <p>Order not found for Invoice ID: <?php echo esc_html($invoice_id); ?></p>
                </div>
            <?php endif; ?>
        <?php else : ?>
            <div class="error-message">
                <p>Invoice ID and Email are required.</p>
            </div>
        <?php endif; ?>
    </div>
</div>

<?php
get_footer(); // Include the theme's footer
?>
