<?php
// paymink-webhook.php

if (!defined('ABSPATH')) {
    exit; // Prevent direct access
}

// Log incoming request for debugging
error_log('Paymink Webhook request: ' . print_r($_POST, true));

add_action('woocommerce_api_paymink_webhook', 'paymink_handle_webhook');

function paymink_handle_webhook() {
    // Check if the request is a valid POST
    if ($_SERVER['REQUEST_METHOD'] !== 'POST') {
        error_log("Invalid request method");
        exit("Invalid request method");
    }

    // Log the entire incoming request for debugging
    error_log("Incoming Paymink Webhook: " . print_r($_POST, true));

    // Get parameters from the incoming Paymink IPN request
    $status = isset($_POST['status']) ? $_POST['status'] : '';
    $signature = isset($_POST['signature']) ? $_POST['signature'] : '';
    $identifier = isset($_POST['identifier']) ? $_POST['identifier'] : ''; // This is the unique identifier (invoice ID)
    $data = isset($_POST['data']) ? $_POST['data'] : [];

    // Log the parameters to help debug
    error_log("Webhook parameters: " . print_r($_POST, true));

    // Ensure all required parameters are present
    if (!$status || !$signature || !$identifier || empty($data)) {
        error_log("Missing required parameters: Identifier or Data");
        exit("Identifier and Data are required.");
    }

    // Get the order based on the identifier (order ID from Paymink)
    $order = wc_get_order($identifier);
    if (!$order) {
        error_log("Order not found for Identifier: {$identifier}");
        exit("Order not found");
    }

    // Get the Paymink secret key from the WooCommerce settings
    $secret_key = get_option('woocommerce_paymink_secret_key');
    if (!$secret_key) {
        error_log("Secret key not found in WooCommerce settings");
        exit("Secret key not found in WooCommerce settings");
    }

    // Generate custom signature for validation
    $customKey = $data['amount'] . $identifier;
    $mySignature = strtoupper(hash_hmac('sha256', $customKey, $secret_key));

    // Log signature and compare
    error_log("Received Signature: {$signature}");
    error_log("Calculated Signature: {$mySignature}");

    // Validate payment status and signature
    if ($status === "success" && $signature === $mySignature) {
        // Payment is successful, complete the order
        $order->payment_complete();
        $order->add_order_note('Payment received via Paymink.');

        // Automatically mark the order as completed
        $order->update_status('completed', 'Payment successfully received and order marked as completed.');

        // Optionally, send email confirmation to customer
        $order->send_order_received_email();

        // Log success
        error_log("Order {$identifier} payment complete and marked as completed.");

        // Redirect to custom order page URL (with order ID)
        $custom_order_url = home_url("/order/{$identifier}");
        wp_redirect($custom_order_url);
        exit; // Exit after redirection
    } else {
        // Payment validation failed, update order status to failed
        $order->update_status('failed', 'Payment validation failed.');
        error_log("Payment validation failed for order {$identifier}");

        // Optionally, log failure reason
        error_log("Failed payment: {$status} | Signature mismatch");

        echo "Payment validation failed";
    }

    exit;
}
?>
