<?php
/**
 * Plugin Name: Paymink Payment Gateway
 * Description: Integrates Paymink payment gateway with WooCommerce.
 * Version: 1.2
 * Author: Ian Rey Torres
 * License: GPL2
 */

if (!defined('ABSPATH')) {
    exit;
}

// Check if WooCommerce is active
if (!in_array('woocommerce/woocommerce.php', apply_filters('active_plugins', get_option('active_plugins')))) {
    return;
}

// Load the payment gateway after WooCommerce is fully loaded
add_action('plugins_loaded', 'paymink_init_gateway', 11);

function paymink_init_gateway() {
    if (class_exists('WC_Payment_Gateway')) {
        require_once plugin_dir_path(__FILE__) . 'includes/class-paymink-gateway.php';
        require_once plugin_dir_path(__FILE__) . 'includes/paymink-api.php';
        require_once plugin_dir_path(__FILE__) . 'includes/paymink-webhook.php';

        // Register the payment gateway in WooCommerce
        add_filter('woocommerce_payment_gateways', 'add_paymink_gateway');
    }
}

function add_paymink_gateway($methods) {
    $methods[] = 'WC_Paymink_Gateway';
    return $methods;
}

// Include admin settings page
if (is_admin()) {
    require_once plugin_dir_path(__FILE__) . 'paymink-settings.php';
}

// Add custom API endpoint to handle the Paymink IPN
add_action('init', 'paymink_register_webhook_endpoint');

function paymink_register_webhook_endpoint() {
    add_rewrite_rule('^paymink-ipn/?$', 'index.php?paymink_webhook=1', 'top');
    flush_rewrite_rules();  // Ensure the rules are flushed after adding
}

// Register custom query var for Paymink webhook
add_filter('query_vars', 'paymink_add_query_vars');

function paymink_add_query_vars($vars) {
    $vars[] = 'paymink_webhook';
    return $vars;
}

// Handle webhook request
add_action('template_redirect', 'paymink_handle_webhook_request');

function paymink_handle_webhook_request() {
    $paymink_webhook = get_query_var('paymink_webhook');
    if ($paymink_webhook) {
        // Include your webhook handling function here
        include_once plugin_dir_path(__FILE__) . 'includes/paymink-webhook.php'; // Correct the path if necessary
        exit; // Stop WordPress from continuing to process the request
    }
}

// Hook to intercept the order page request and load the custom template
add_action('template_include', 'paymink_handle_order_page', 10);

function paymink_handle_order_page($template) {
    // Check if the current URL is '/order-success'
    if (is_page('order-success')) {
        // Include the custom order template from the plugin
        return plugin_dir_path(__FILE__) . 'includes/paymink-order-template.php';
    }
    return $template;
}

// Register the order ID as a custom query var
add_filter('query_vars', 'paymink_add_order_id_query_var');

function paymink_add_order_id_query_var($vars) {
    $vars[] = 'order_id'; // Add custom query var to get order ID
    return $vars;
}

// Enqueue custom styles for the order success page
function paymink_enqueue_styles() {
    // Check if we're on the correct page (order success page)
    if (is_page('order-success')) { // Adjust the page slug if necessary
        wp_enqueue_style('paymink-order-success', plugin_dir_url(__FILE__) . 'assets/css/style.css');
    }
}
add_action('wp_enqueue_scripts', 'paymink_enqueue_styles');
